package com.dahe.mylibrary.net;

import com.google.gson.Gson;

import org.json.JSONObject;

import java.io.IOException;
import java.lang.reflect.Type;
import java.nio.charset.Charset;

import okhttp3.ResponseBody;
import okio.Buffer;
import okio.BufferedSource;
import retrofit2.Converter;


public class GsonResponseBodyConverter<T> implements Converter<ResponseBody, T> {
    private final Gson gson;
    private final Type type;


    public GsonResponseBodyConverter(Gson gson, Type type) {
        this.gson = gson;
        this.type = type;
    }

    @Override
    public T convert(ResponseBody value) throws IOException {

        //为了不消耗buffer，我们这里使用source先获得buffer对象，然后clone()后使用
        BufferedSource source = value.source();
        source.request(Long.MAX_VALUE); // Buffer the entire body.
        //获得返回的数据
        Buffer buffer = source.buffer();
        //使用前clone()下，避免直接消耗
        String responseBodyStr = buffer.clone().readString(Charset.forName("UTF-8"));
        try {

            JSONObject jsonObject = new JSONObject(responseBodyStr);
            int code = jsonObject.optInt("code");
            if (-1 == code) {
                jsonObject.put("data", new JSONObject());
//                ErrorResponse errorResponse = gson.fromJson(response, ErrorResponse.class);
                //抛一个自定义ResultException 传入失败时候的状态码，和信息

                throw new ResultException(-1, "errorResponse.getMsg()");

//                return gson.fromJson(responseBodyStr,type);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return gson.fromJson(responseBodyStr, type);


//        String response = value.string();
//        //先将返回的json数据解析到Response中，如果code==200，则解析到我们的实体基类中，否则抛异常
//        Response httpResult = gson.fromJson(response, Response.class);
//        if (httpResult.code()==200){
//            //200的时候就直接解析，不可能出现解析异常。因为我们实体基类中传入的泛型，就是数据成功时候的格式
//            return gson.fromJson(response,type);
//        }else {
//            ErrorResponse errorResponse = gson.fromJson(response,ErrorResponse.class);
//            //抛一个自定义ResultException 传入失败时候的状态码，和信息
//            try {
//                throw new ResultException(errorResponse.getCode(),errorResponse.getMsg());
//            } catch (ResultException e) {
//                e.printStackTrace();
//            }
//            return null;
//        }
    }
}

